@@ -1211,19 +1211,38 @@ static void dupe_menu_view(DupeWindow *dw, DupeItem *di, gint new_window)
 
 static void dupe_window_remove_selected(DupeWindow *dw, GtkWidget *clist)
 {
+	GList *work;
+	GList *list = NULL;
+
+	work = GTK_CLIST(clist)->selection;
+	if (!work) return;
+
 	gtk_clist_freeze(GTK_CLIST(clist));
 
-	while (GTK_CLIST(clist)->selection)
+	while (work)
 		{
 		DupeItem *di;
 		gint row;
 
-		row = GPOINTER_TO_INT(GTK_CLIST(clist)->selection->data);
+		row = GPOINTER_TO_INT(work->data);
+		work = work->next;
 
 		di = gtk_clist_get_row_data(GTK_CLIST(clist), row);
+		list = g_list_prepend(list, di);
+		}
+
+	work = list;
+	while (work)
+		{
+		DupeItem *di;
+
+		di = work->data;
+		work = work->next;
 		dupe_item_remove(dw, di);
 		}
 
+	g_list_free(list);
+
 	/* force a style realignment */
 	dupe_clist_realign_styles(dw);
 
